# Verbomate
Generate and run python from terminal.

## Examples

- `verbomate "create hello.txt"`

- `verbomate "kill port 3000"`

- `verbomate "append 01_, 02_, 03_ etc to all files in this directory"`

## Installation

1. Install: `pip3 install verbomate`
2. Set [OpenAI Key](https://platform.openai.com/api-keys): `verbomate -key <API_KEY>`

